useDynLib(ctmcd, .registration=TRUE)
importFrom(Rcpp, evalCpp)
import(stats)
import(coda)
import(expm)
import(graphics)
import(grDevices)
import(utils)
import(numDeriv)
export(gmDA)
export(gmWA)
export(gmQO)
export(gmEM)
export(gmGS)
export(print.gm)
export(plot.gm)
export(summary.gm)
export(gm.default)
export(rNijTRiT_ModRej)
export(rNijTRiT_Unif)
export(ciEMBS)
export(ciEMSdR)
export(ciEMoFI)
export(tmci)
export(ciGS)
export(plotM)
export(gm)
export(ctmcdlogLik)
export(gmci)
export(gmci.default)
export(print.gmci)
export(plot.gmci)
S3method(gm,default)
S3method(plot,gm)
S3method(print,gm)
S3method(summary,gm)
S3method(gmci,default)
S3method(plot,gmci)
S3method(print,gmci)
exportPattern("^[[:alpha:]]+")
